@@ -44,7 +44,7 @@ Templaer - универсальный CLI шаблонизатор конфиг
 -c Путь_context.json                = Указать путь к файлу, из которого будут браться данными для шаблонов.
 -f Файл0 Файл1                      = Указать конкретные файлы, с расширением `.tpl`.
 -d ПутьДиректории0 ПутьДиректории1  = Указать путь к директории, в которой будут искаться все файлы с расширением `.tpl`.
--e_                                 = Если указа этот флаг то также создастся `.env` файл, в туже папку где `context.json`
+-e_                                 = Если указа этот флаг то также создастся `.env` файл, в те же папки где есть файлы `.tpl`
 
     """
 
@@ -53,6 +53,8 @@ Templaer - универсальный CLI шаблонизатор конфиг
         argv[0],
         argv[1:],
     )
+    # Список директорий в которых есть шаблонные файлы
+    use_paths_dirs = set()
     ##
     # Ели не переданы ни каких данных то выводим документацию по CLI
     ##
@@ -78,6 +80,8 @@ Templaer - универсальный CLI шаблонизатор конфиг
             template_str: str = pathlib.Path(_files).resolve().read_text()
             build_text: str = build_conf(template_str, context)
             save_tpl_file(_files, build_text)
+            # Добавить папку в используемые
+            use_paths_dirs.add(pathlib.Path(_files).parent.resolve())
     ##
     # Находим файлы которые оканчиваются на `.tpl`, в указанной директории. И собираем шаблон
     ##
@@ -89,6 +93,8 @@ Templaer - универсальный CLI шаблонизатор конфиг
                 template_str: str = pathlib.Path(_files).resolve().read_text()
                 build_text: str = build_conf(template_str, context)
                 save_tpl_file(_files, build_text)
+                # Добавить папку в используемые
+                use_paths_dirs.add(pathlib.Path(_files).parent.resolve())
     ###
     # Если нужно, то создаем env файл
     ##
@@ -96,7 +102,13 @@ Templaer - универсальный CLI шаблонизатор конфиг
         # Если контекст в типе словарь
         if type(context) == dict:
             # То конвертируем словарь в строку для .env файлов
-            write_text = [f'{k}={v}' for k, v in context.items()]
+            write_text = []
+            for k, v in context.items():
+                if type(v) == str:
+                    write_text.append(f'{k}="{v}"')
+                else:
+                    write_text.append(f'{k}={v}')
+            # for _path in use_paths_dirs:
             # Записываем в файл `.env` в туже папку где `context.json`
             (path_to_context.parent / '.env').write_text(
                 '\n'.join(write_text)
